<?php
/**
 * Functions
 */

/******************************************************************************
                        Global Functions
******************************************************************************/

//  Add widget support shortcodes
    add_filter('widget_text', 'do_shortcode');
    
// Custom Editor Style Support
    add_editor_style();

// Support for Featured Images
    add_theme_support( 'post-thumbnails' ); 

// Custom Background
    add_theme_support( 'custom-background', array('default-color' => 'fff'));

// Custom Header
    add_theme_support( 'custom-header', array(
        'default-image' => get_template_directory_uri() . '/images/custom-logo.png',
        'height'        => '200',
        'flex-height'    => true,
        'uploads'       => true,
        'header-text'   => false
    ) );

// Register Navigation Menu
    register_nav_menus( array(
        'header-menu' => 'Header Menu',
        'footer-menu' => 'Footer Menu'
    ) );

// Navigation Menu Adjustments

    /* Add class to navigation sub-menu */
    class foundation_navigation extends Walker_Nav_Menu {

    function start_lvl(&$output, $depth) {
        $indent = str_repeat("\t", $depth);
        $output .= "\n$indent<ul class=\"dropdrown_menu dropdown\">\n";
    }

    function display_element( $element, &$children_elements, $max_depth, $depth=0, $args, &$output ) {
        $id_field = $this->db_fields['id'];
        if ( !empty( $children_elements[ $element->$id_field ] ) ) {
            $element->classes[] = 'has-dropdown';
        }
            Walker_Nav_Menu::display_element( $element, $children_elements, $max_depth, $depth, $args, $output );
        }
    }

    /* Display Pages In Navigation Menu */
    if ( ! function_exists( 'foundation_page_menu' ) ) :
	function foundation_page_menu() {
		$pages_args = array(
		    'sort_column' => 'menu_order, post_title',
		    'menu_class'  => '',
		    'include'     => '',
		    'exclude'     => '',
		    'echo'        => true,
		    'show_home'   => false,
		    'link_before' => '',
		    'link_after'  => ''
		);

		wp_page_menu($pages_args);
	}
    endif;
    

// Create pagination
    function foundation_pagination() {

	global $wp_query;

	$big = 999999999;

	    $links = paginate_links( array(
		'base' => str_replace( $big, '%#%', esc_url( get_pagenum_link( $big ) ) ),
		'format' => '?paged=%#%',
		'prev_next' => true,
		'prev_text' => '&laquo;',
		'next_text' => '&raquo;',
		'current' => max( 1, get_query_var('paged') ),
		'total' => $wp_query->max_num_pages,
		'type' => 'list'
		)
	    );

	$pagination = str_replace('page-numbers','pagination',$links);

	echo $pagination;
    }

// Register Sidebars

    /* Sidebar Home */
        register_sidebar( array(
            'id' => 'foundation_home',
            'name' => __( 'Home Sidebar' ),
            'description' => __( 'This sidebar is located on the home page.'),
            'before_widget' => '<aside id="%1$s" class="widget %2$s">',
            'after_widget' => '</aside>',
            'before_title' => '<h5>',
            'after_title' => '</h5>',
        ));
	
    /* Sidebar Suivi Medical */
        register_sidebar( array(
            'id' => 'foundation_suivi',
            'name' => __( 'Suivi Medical' ),
            'description' => __( 'This sidebar is located on the Suivi Medical page.'),
            'before_widget' => '<aside id="%1$s" class="widget %2$s">',
            'after_widget' => '</aside>',
            'before_title' => '<h5>',
            'after_title' => '</h5>',
        ));
	
    /* Sidebar Footer */
        register_sidebar( array(
            'id' => 'foundation_footer',
            'name' => __( 'Footer' ),
            'description' => __( 'This sidebar is located on the footer of each page.'),
            'before_widget' => '<aside id="%1$s" class="widget %2$s">',
            'after_widget' => '</aside>',
            'before_title' => '<h5>',
            'after_title' => '</h5>',
        ));

// Remove #more anchor from posts
    function remove_more_jump_link($link) { 
        $offset = strpos($link, '#more-');
        if ($offset) { $end = strpos($link, '"',$offset); }
        if ($end) { $link = substr_replace($link, '', $offset, $end-$offset); }
        return $link;
    }
    add_filter('the_content_more_link', 'remove_more_jump_link');

    
// Custom Post Excerpt
    if ( ! function_exists( 'foundation_excerpt' ) ) :

	function content($limit) {
	    $content = explode(' ', get_the_content(), $limit);
	    if (count($content)>=$limit) {
	      array_pop($content);
	      $content = implode(" ",$content).'...<a href="'. get_permalink($post->ID) . '" class="read_more">Lire Plus</a>';
	    } else {
	      $content = implode(" ",$content);
	    }

	    $content = preg_replace('/\[.+\]/','', $content);
	    $content = apply_filters('the_content', $content);
	    $content = str_replace(']]>', ']]&gt;', $content);
	    return $content;
      }

    endif;

// Disable wordpress jQuery
    function modify_jquery() {
        if (!is_admin()) {
            // comment out the next two lines to load the local copy of jQuery
            wp_enqueue_script('jquery');
        }
    }
    add_action('init', 'modify_jquery');

/******************************************************************************************************************************
			    Enqueue Scripts and Styles for Front-End
*******************************************************************************************************************************/
if (!is_admin()) {

// Load JavaScripts
   
    wp_enqueue_script( 'foundation', get_template_directory_uri() . '/js/foundation.js', null, null, true );
    wp_enqueue_script( 'global', get_template_directory_uri() . '/js/global.js', null, null, true );
    wp_enqueue_script( 'respond', get_template_directory_uri() . '/js/plugins/respond.js', null, null, true );
   
    
		
// Load Stylesheets
    //core
    wp_enqueue_style( 'foundation', get_template_directory_uri().'/css/foundation.css' );
    wp_enqueue_style( 'normalize', get_template_directory_uri().'/css/core/normalize.css' );
    wp_enqueue_style( 'customizer', get_template_directory_uri().'/css/core/customizer.css' );
    //plugins
    wp_enqueue_style( 'font-awesome.min', get_template_directory_uri().'/css/plugins/font-awesome.min.css' );
    //system
    wp_enqueue_style( 'style', get_template_directory_uri().'/style.css' );/*2nd priority*/
    wp_enqueue_style( 'media-screens', get_template_directory_uri().'/css/media-screens.css' );/*1st priority*/


   
    

}

 // Initialise Foundation JS
    function foundation_js_init () {
        echo '<script>!function ($) { $(document).foundation(); }(window.jQuery); </script>';
    }
    add_action('wp_footer', 'foundation_js_init', 50); 
    
/******************************************************************************
			    Additional Functions
*******************************************************************************/

// Stick Admin Bar To The Top
    if (!is_admin()) {
        add_action('get_header', 'my_filter_head');

        function my_filter_head() {
            remove_action('wp_head', '_admin_bar_bump_cb');
        }

        function stick_admin_bar() {
            echo "
            <style type='text/css'>
                body.admin-bar {margin-top:32px !important}	
                @media screen and (max-width: 782px) {
                    body.admin-bar { margin-top:46px !important }
                }
                @media screen and (max-width: 600px) {
                    body.admin-bar { margin-top:46px !important }
                    html #wpadminbar{ margin-top: -46px; }
                }
            </style>
            ";
        }

        add_action('admin_head', 'stick_admin_bar');
        add_action('wp_head', 'stick_admin_bar');
    }
    
    
    

/*********************** PUT YOU FUNCTIONS BELOW ********************************/
    
add_image_size( 'homepage-thumb', 155, 155, true ); // (cropped)    
add_image_size( 'le-cabinet', 280, 185, true ); // (cropped)    
add_image_size( 'conseils', 300, 250, true ); // (cropped)    
add_image_size( 'single', 480, 300, true ); // (cropped)     


// Deregister Default "POST" type
add_action('admin_menu','remove_default_post_type');

function remove_default_post_type() {
	remove_menu_page('edit.php');
}

// Fix tags for CPT
function post_type_tags_fix($request) {
    if ( isset($request['tag']) && !isset($request['post_type']) )
    $request['post_type'] = 'any';
    return $request;
} 
add_filter('request', 'post_type_tags_fix');
    
//Login Styling

function my_login_logo() { ?>
    <style type="text/css">
        body.login div#login h1 a {
                background-image: url(<?php echo bloginfo('url'); ?>/wp-content/uploads/2014/10/login-logo.png););
                padding-bottom: 30px;
    	    background-size: 100%;
    	    height: 100px;
    	    width: 100%;
            }
    	body.login {
    	    background: #e3e3e3;
    	    background-size:cover;
    	    background-position:center top;
    	}
    	#login {
    	    width: 410px;
    	}

    	#login #nav a,
    	#login #backtoblog a,
    	#login #nav a:hover,
    	#login #backtoblog a:hover {
    	    color: #fff;
    	}

    	#login #nav a:hover,
    	#login #backtoblog a:hover {
    	    text-decoration: underline
    	}

    	#login #wp-submit {
    	    background: #F7413E;
    	    border-radius: 0;
    	    border: none;
    	    border-left: 1px solid #FD6663;
    	    border-bottom: 4px solid #BE3B39;
    	    color: #fff;			
    	}

    	#login #wp-submit:hover {
    	    color: #fff;
    	    opacity: .95;
    	}

    	.login #nav a, .login #backtoblog a {
    	    color: #BE3B39 !important;
    	}

    	.login #nav {
    	    margin: 15px 0 0;
	    padding: 0 0;
	    text-align: center;
    	}
	.login #backtoblog{
	    text-align: center;
	}

    </style>
<?php }
add_action( 'login_enqueue_scripts', 'my_login_logo' );    

// Add special field for new user
add_action( 'show_user_profile', 'extra_user_profile_fields' );
add_action( 'edit_user_profile', 'extra_user_profile_fields' );

function extra_user_profile_fields( $user ) { ?>
<h3><?php _e("Informations de profil supplémentaire", "blank"); ?></h3>

<table class="form-table">
<tr>
<th><label for="nom_prenom"><?php _e("Nom et prénom de l'enfant"); ?></label></th>
<td>
<input type="text" name="nom_prenom" id="nom_prenom" value="<?php echo esc_attr( get_the_author_meta( 'nom_prenom', $user->ID ) ); ?>" class="regular-text" /><br />
</td>
</tr>
</table>
<?php }

add_action( 'personal_options_update', 'save_extra_user_profile_fields' );
add_action( 'edit_user_profile_update', 'save_extra_user_profile_fields' );

add_action('user_register', 'register_post_fields');
function register_post_fields($user_id, $password='', $meta=array())  {
    $userdata = array();
    $userdata['ID'] = $user_id;
    $userdata['nom_prenom'] = $_POST['nom_prenom'];
    wp_update_user($userdata);
    update_usermeta( $user_id, 'nom_prenom', $_POST['nom_prenom'] );	
}


//unique_pass
add_filter('protected_title_format', 'blank');
function blank($title) {
    return '%s';
}


/*******************************************************************************/
    
    
?>